@@ -8,12 +8,16 @@ from docx.text.parfmt import ParagraphFormat
 from pandas.core.frame import DataFrame
 
 from eda_report.content import _ReportContent
+from eda_report.multivariate import _select_dtypes
 
 logging.basicConfig(
     format="[%(levelname)s %(asctime)s.%(msecs)03d] %(message)s",
     level=logging.INFO,
     datefmt="%H:%M:%S",
 )
+# Set matplotlib logging level to WARNING.
+mpl_logger = logging.getLogger("matplotlib")
+mpl_logger.setLevel(logging.WARNING)
 
 
 class ReportDocument(_ReportContent):
@@ -70,7 +74,7 @@ class ReportDocument(_ReportContent):
         self._create_title_page()
         self._get_univariate_analysis()
 
-        if hasattr(self.multivariable, "var_pairs"):
+        if self.multivariable._correlation_values is not None:
             self._get_bivariate_analysis()
 
         self._to_file()
@@ -103,14 +107,17 @@ class ReportDocument(_ReportContent):
 
     def _get_numeric_overview_table(self) -> None:
         """Create a table with an overview of the numeric features present."""
-        if self.multivariable.numeric_cols is not None:
+        numeric_cols = _select_dtypes(self.multivariable.data, "number")
+        if numeric_cols is None:
+            return None
+        else:
             heading = self.document.add_heading(
                 "Overview of Numeric Features", level=1
             )
             self._format_heading_spacing(heading.paragraph_format)
             # count | mean | std | min | 25% | 50% | 75% | max
             self._create_table(
-                data=self.multivariable.numeric_stats,
+                data=self.multivariable._numeric_stats,
                 header=True,
                 column_widths=(1.2,) + (0.7,) * 8,
                 font_size=8.5,
@@ -121,14 +128,19 @@ class ReportDocument(_ReportContent):
         """Create a table with an overview of the categorical features
         present.
         """
-        if self.multivariable.categorical_cols is not None:
+        categorical_cols = _select_dtypes(
+            self.multivariable.data, "bool", "category", "object"
+        )
+        if categorical_cols is None:
+            return None
+        else:
             heading = self.document.add_heading(
                 "Overview of Categorical Features", level=1
             )
             self._format_heading_spacing(heading.paragraph_format)
             # column-name | count | unique | top | freq | relative freq
             self._create_table(
-                data=self.multivariable.categorical_stats,
+                data=self.multivariable._categorical_stats,
                 header=True,
                 column_widths=(1.2,) + (0.9,) * 5,
                 font_size=8.5,
@@ -156,7 +168,7 @@ class ReportDocument(_ReportContent):
             normality_tests = self.normality_tests.get(var_name)
 
             heading = self.document.add_heading(
-                f"1.{idx}. {var_name}".title(), level=2
+                f"1.{idx} {var_name}".title(), level=2
             )
             self._format_heading_spacing(
                 heading.paragraph_format, before=12, after=5
@@ -221,12 +233,14 @@ class ReportDocument(_ReportContent):
         variables.
         """
         bivariate_heading = self.document.add_heading(
-            "2. Bivariate Analysis (Correlation)", level=1
+            "2. Bivariate Analysis", level=1
         )
         self._format_heading_spacing(
             bivariate_heading.paragraph_format, before=0
         )
 
+        overview_heading = self.document.add_heading("2.1 Overview", level=2)
+        self._format_heading_spacing(overview_heading.paragraph_format)
         self.document.add_picture(
             self.bivariate_graphs["correlation_plot"],
             width=Inches(6.7),
@@ -235,9 +249,15 @@ class ReportDocument(_ReportContent):
         picture_paragraph.alignment = WD_ALIGN_PARAGRAPH.CENTER
         self.document.add_page_break()
 
+        pairwise_heading = self.document.add_heading(
+            "2.2 Regression Plots (Top 20)", level=2
+        )
+        self._format_heading_spacing(
+            pairwise_heading.paragraph_format, before=0
+        )
         for idx, var_pair in enumerate(self.bivariate_summaries, start=1):
             heading = self.document.add_heading(
-                f"2.{idx} {var_pair[0]} vs {var_pair[1]}".title(), level=2
+                f"2.2.{idx} {var_pair[0]} vs {var_pair[1]}".title(), level=3
             )
             self._format_heading_spacing(
                 heading.paragraph_format, before=16, after=5
