@@ -230,7 +230,7 @@ def bar_plot(
 
     # Include no more than 10 of the most common values
     top_10 = data.value_counts().nlargest(10)
-    bars = ax.bar(top_10.index, top_10, alpha=0.8, color=color)
+    bars = ax.bar(top_10.index.map(str), top_10, alpha=0.8, color=color)
     ax.bar_label(bars, labels=[f"{x:,.0f}" for x in top_10], padding=2)
 
     if (num_unique := data.nunique()) > 10:
@@ -313,24 +313,24 @@ def plot_correlation(
     if not isinstance(variables, MultiVariable):
         variables = MultiVariable(variables)
 
-    pairs = list(variables.var_pairs)
-    corr_data = (
-        variables.correlation_df.unstack()  # get MultiIndex of cols
-        .loc[pairs]  # select unique pairs
-        .sort_values(key=abs)  # sort by magnitude
-        .tail(max_pairs)  # select top `max_pairs` (default 20)
-    )
-    labels = corr_data.index.map(" vs ".join)
+    if variables._correlation_values is None:
+        return None
+
+    # Show at most `max_pairs` numeric pairs.
+    pairs_to_show = variables._correlation_values[:max_pairs]
+    # Reverse items so largest values appear at the top.
+    corr_data = dict(reversed(pairs_to_show))
+    labels = [" vs ".join(pair) for pair in corr_data.keys()]
 
     fig = Figure(figsize=(7, 6.3))
     ax = fig.subplots()
-    ax.barh(labels, corr_data, edgecolor="#777")
-    ax.set_xlim(-1, 1)
+    ax.barh(labels, corr_data.values(), edgecolor="#222", linewidth=0.5)
+    ax.set_xlim(-1.1, 1.1)
     ax.spines["left"].set_position("zero")
     ax.yaxis.set_visible(False)  # hide y-axis labels
 
     for p, label in zip(ax.patches, labels):
-        p.set_alpha(abs(p.get_width()))
+        p.set_alpha(min(1, abs(p.get_width()) + 0.1))
 
         if p.get_width() < 0:
             p.set_facecolor(color_neg)
@@ -434,27 +434,26 @@ def _plot_multivariable(
         Optional[Dict]: A dictionary with a correlation plot and regression
         plots.
     """
-    if hasattr(variables, "var_pairs"):
-        var_pairs = list(variables.var_pairs)
-
-        if len(variables.var_pairs) > 50:
-            # Take the top 50 var_pairs by magnitude of correlation.
-            # 50 var_pairs == 25+ pages
-            # 20 numeric columns == upto 190 pairs (95+ pages).
-            var_pairs = (
-                variables.correlation_df.unstack()[var_pairs]
-                .sort_values(key=abs)
-                .tail(50)
-                .index
-            )
+    if variables._correlation_values is None:
+        return None
+    else:
+        # Take the top 20 pairs by magnitude of correlation.
+        # 20 var_pairs ≈ 10+ pages
+        # 20 numeric columns == 190 var_pairs ≈ 95+ pages.
+        pairs_to_include = [
+            pair for pair, _ in variables._correlation_values[:20]
+        ]
         with Pool() as p:
             paired_data_gen = [
-                (variables.data.loc[:, pair], color) for pair in var_pairs
+                (variables.data.loc[:, pair], color)
+                for pair in pairs_to_include
             ]
             bivariate_regression_plots = dict(
                 tqdm(
+                    # Plot in parallel processes
                     p.imap(_plot_regression, paired_data_gen),
-                    total=len(var_pairs),
+                    # Progress-bar options
+                    total=len(pairs_to_include),
                     bar_format=(
                         "{desc} {percentage:3.0f}%|{bar:35}| "
                         "{n_fmt}/{total_fmt} pairs."
@@ -471,5 +470,3 @@ def _plot_multivariable(
                 for var_pair, plot in bivariate_regression_plots.items()
             },
         }
-    else:
-        return None
