@@ -1,6 +1,6 @@
 from collections.abc import Iterable
 from textwrap import shorten
-from typing import Optional, Union
+from typing import Optional, Tuple
 
 from pandas import DataFrame, Series
 from pandas.api.types import (
@@ -15,8 +15,8 @@ from eda_report.validate import validate_univariate_input
 
 class Variable:
 
-    """Defines objects that evaluate the general properties of one-dimensional
-    datasets, such as data type and missing values.
+    """Defines objects that analyze one-dimensional datasets to obtain summary
+    statistics, and evaluate properties such as data type and missing values.
 
     Input data is internally held as a :class:`~pandas.Series` in order
     to leverage pandas_ built-in statistical methods, as well as functions
@@ -29,6 +29,14 @@ class Variable:
         data (Iterable): The data to analyze.
         name (str, optional): The name to assign the variable. Defaults to
             None.
+
+    Examples:
+        .. literalinclude:: examples.txt
+           :lines: 6-22
+        .. literalinclude:: examples.txt
+           :lines: 26-53
+        .. literalinclude:: examples.txt
+           :lines: 57-76
     """
 
     def __init__(self, data: Iterable, *, name: str = None) -> None:
@@ -53,6 +61,17 @@ class Variable:
         #: ``number (percentage%)`` e.g "4 (16.67%)".
         self.missing = self._get_missing_values_info()
 
+        self._get_summary_statistics()
+
+    def __repr__(self) -> str:
+        """Get the string representation of a variable based on it's summary
+        statistics.
+
+        Returns:
+            str: Summary statistics.
+        """
+        return repr(self.summary_statistics)
+
     def rename(self, name: str = None) -> None:
         """Rename the variable as specified.
 
@@ -105,21 +124,23 @@ class Variable:
                 f"{missing_values:,} ({missing_values / len(self.data):.2%})"
             )
 
+    def _get_summary_statistics(self) -> None:
+        """Compute summary statistics for the variable based on data type."""
+        if self.var_type == "numeric":
+            stats = _NumericStats(self)
+        elif self.var_type == "datetime":
+            stats = _DatetimeStats(self)
+        else:
+            stats = _CategoricalStats(self)
 
-class CategoricalStats:
-    """Get descriptive statistics for a categorical
-    :class:`~eda_report.univariate.Variable`.
+        self.summary_statistics = stats
 
-    .. note::
-       Not meant to be used directly: use the :func:`eda_report.summarize`
-       function instead.
+
+class _CategoricalStats:
+    """Get descriptive statistics for a categorical variable.
 
     Args:
         variable (Variable): The data to analyze.
-
-    Example:
-        .. literalinclude:: examples.txt
-           :lines: 6-23
     """
 
     def __init__(self, variable: Variable) -> None:
@@ -176,20 +197,11 @@ class CategoricalStats:
         return most_common_items.apply(lambda x: f"{x:,} ({x / n:.2%})")
 
 
-class DatetimeStats:
-    """Get descriptive statistics for a datetime
-    :class:`~eda_report.univariate.Variable`.
-
-    .. note::
-       Not meant to be used directly: use the :func:`eda_report.summarize`
-       function instead.
+class _DatetimeStats:
+    """Get descriptive statistics for a datetime variable.
 
     Args:
         variable (Variable): The data to analyze.
-
-    Example:
-        .. literalinclude:: examples.txt
-           :lines: 27-46
     """
 
     def __init__(self, variable: Variable) -> None:
@@ -235,20 +247,11 @@ class DatetimeStats:
         )
 
 
-class NumericStats:
-    """Get descriptive statistics for a numeric
-    :class:`~eda_report.univariate.Variable`.
-
-    .. note::
-       Not meant to be used directly: use the :func:`eda_report.summarize`
-       function instead.
+class _NumericStats:
+    """Get descriptive statistics for a numeric variable.
 
     Args:
         variable (Variable): The data to analyze.
-
-    Example:
-        .. literalinclude:: examples.txt
-           :lines: 50-78
     """
 
     def __init__(self, variable) -> None:
@@ -345,28 +348,14 @@ class NumericStats:
             }
         )
         results["p-value"] = results["p-value"].apply(lambda x: f"{x:.7f}")
+
         return results
 
 
-def analyze_univariate(
-    data: Iterable, *, name: str = None
-) -> Union[CategoricalStats, DatetimeStats, NumericStats]:
-    """Convert a one-dimensional dataset into a
-    :class:`~eda_report.univariate.Variable`, and get summary statistics.
-
-    Args:
-        data (Iterable): The data to analyze.
-        name (str, optional): The name to assign the variable. Defaults to
-            None.
-
-    Returns:
-        Union[CategoricalStats, DatetimeStats, NumericStats]: Summary
-        statistics
+def _analyze_univariate(name_and_data: Tuple) -> Variable:
+    """Helper function used to concurrently analyze data with multiprocessing.
     """
+    name, data = name_and_data
     var = Variable(data, name=name)
-    if var.var_type == "numeric":
-        return NumericStats(variable=var)
-    elif var.var_type == "datetime":
-        return DatetimeStats(variable=var)
-    else:
-        return CategoricalStats(variable=var)
+
+    return name, var
